Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::sliding_view_detail::sv_base< Rng > Member List

This is the complete list of members for ranges::v3::sliding_view_detail::sv_base< Rng >, including all inherited members.

at(range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n]) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
at(range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n]) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
back() | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
back() const | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
base() noexcept (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
base() const noexcept | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
begin() | ranges::v3::view_facade< sliding_view< Rng >, Cardinality > |
begin() const | ranges::v3::view_facade< sliding_view< Rng >, Cardinality > |
cache() & (defined in ranges::v3::sliding_view_detail::sv_base< Rng >) | ranges::v3::sliding_view_detail::sv_base< Rng > | protected
cache() const & (defined in ranges::v3::sliding_view_detail::sv_base< Rng >) | ranges::v3::sliding_view_detail::sv_base< Rng > | protected
derived() noexcept (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > | protected
derived() const noexcept | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > | protected
empty() const noexcept | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
empty() const noexcept(noexcept(bool(ranges::begin(std::declval< D const & >())==ranges::end(std::declval< D const & >())))) (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
end() | ranges::v3::view_facade< sliding_view< Rng >, Cardinality > |
end() const | ranges::v3::view_facade< sliding_view< Rng >, Cardinality > |
front() | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
front() const | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
n_ (defined in ranges::v3::sliding_view_detail::sv_base< Rng >) | ranges::v3::sliding_view_detail::sv_base< Rng > | protected
operator bool() const noexcept(noexcept(ranges::empty(std::declval< D const & >()))) (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > | explicit
operator Container() | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator Container() const | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator!() const noexcept(noexcept(decltype(ranges::empty(std::declval< D const & >()))(ranges::empty(std::declval< D const & >())))) -> decltype(ranges::empty(std::declval< D const & >())) (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator=(view_adaptor &&)=default (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
operator=(view_adaptor const &)=default (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
operator=(view_interface &&)=default (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator=(view_interface const &)=default (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](range_difference_type_t< D > n) -> decltype(std::declval< D & >().begin()[n]) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](range_difference_type_t< D > n) const -> decltype(std::declval< D const & >().begin()[n]) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, detail::from_end_< range_difference_type_t< D >>> offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< range_difference_type_t< D >, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &-> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) const &-> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
operator[](detail::slice_bounds< detail::from_end_< range_difference_type_t< D >>, end_fn > offs) &&-> decltype(std::declval< Slice >()(std::declval< D >(), offs.from, offs.to)) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
size() const | ranges::v3::sliding_view_detail::sv_base< Rng > |
size() | ranges::v3::sliding_view_detail::sv_base< Rng > |
sv_base()=default (defined in ranges::v3::sliding_view_detail::sv_base< Rng >) | ranges::v3::sliding_view_detail::sv_base< Rng > |
sv_base(Rng rng, range_difference_type_t< Rng > n) (defined in ranges::v3::sliding_view_detail::sv_base< Rng >) | ranges::v3::sliding_view_detail::sv_base< Rng > |
view_adaptor()=default (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
view_adaptor(view_adaptor &&)=default (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
view_adaptor(view_adaptor const &)=default (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > |
view_adaptor(Rng &&rng) (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > | explicit
view_interface()=default (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
view_interface(view_interface &&)=default (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
view_interface(view_interface const &)=default (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > |
~view_adaptor()=default (defined in ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value >) | ranges::v3::view_adaptor< sliding_view< Rng >, Rng, is_finite< Rng >::value ? finite :range_cardinality< Rng >::value > | protected
~view_interface()=default (defined in ranges::v3::view_interface< sliding_view< Rng >, Cardinality >) | ranges::v3::view_interface< sliding_view< Rng >, Cardinality > | protected